@@ -3,40 +3,21 @@ use std::error::Error;
 
 pub fn from(s: &str) -> Result<Vec<u8>, Box<dyn Error>> {
 
-    let mut binary_str: String = String::new();
+    let mut res: Vec<u8> = vec![];
 
-    let mut integer_str: String = s.to_string();
+    let mut i_str = s.to_string();
 
-    while integer_str != "0".to_string() {
+    while i_str != "0".to_string() {
 
-        let (s_half, rem) = half(&integer_str);
+        let (s_half, rem) = half(&i_str);
 
-        integer_str = s_half;
+        i_str = s_half;
 
-        binary_str.push_str(&rem.to_string());
+        res.push(rem);
 
     }
 
-    let mut res: Vec<u8> = Vec::new();
-
-    (0..binary_str.len())
-        .step_by(8)
-        .for_each(|x| {
-            
-            let end =
-                if (x + 8) > binary_str.len() {
-                    binary_str.len()
-                } else { x + 8 };
-
-            let slice: &str = &binary_str[x..end];
-
-            let rev_slice: String = slice.chars().rev().collect::<String>();
-
-            let byte: u8 = u8::from_str_radix(&rev_slice, 2).unwrap();
-
-            res.push(byte);
-
-        });
+    res.reverse();
 
     Ok(res)
 
